summaryrefslogtreecommitdiff
path: root/tests/projects/ascendc/mixed_binary
diff options
context:
space:
mode:
Diffstat (limited to 'tests/projects/ascendc/mixed_binary')
-rw-r--r--tests/projects/ascendc/mixed_binary/src/helper.aicpu6
-rw-r--r--tests/projects/ascendc/mixed_binary/src/main.asc25
-rw-r--r--tests/projects/ascendc/mixed_binary/test.lua9
-rw-r--r--tests/projects/ascendc/mixed_binary/xmake.lua6
4 files changed, 46 insertions, 0 deletions
diff --git a/tests/projects/ascendc/mixed_binary/src/helper.aicpu b/tests/projects/ascendc/mixed_binary/src/helper.aicpu
new file mode 100644
index 000000000..a11afdd90
--- /dev/null
+++ b/tests/projects/ascendc/mixed_binary/src/helper.aicpu
@@ -0,0 +1,6 @@
+#include "aicpu_api.h"
+
+__global__ __aicpu__ uint32_t hello_world(void *args) {
+ AscendC::printf("Hello World!!!\n");
+ return 0;
+}
diff --git a/tests/projects/ascendc/mixed_binary/src/main.asc b/tests/projects/ascendc/mixed_binary/src/main.asc
new file mode 100644
index 000000000..9bc0999bd
--- /dev/null
+++ b/tests/projects/ascendc/mixed_binary/src/main.asc
@@ -0,0 +1,25 @@
+#include "acl/acl.h"
+
+struct KernelArgs {
+ int mode;
+};
+
+extern __global__ __aicpu__ uint32_t hello_world(void *args);
+
+int32_t main(int argc, char const *argv[]) {
+ aclInit(nullptr);
+ int32_t deviceId = 0;
+ aclrtSetDevice(deviceId);
+ aclrtStream stream = nullptr;
+ aclrtCreateStream(&stream);
+
+ struct KernelArgs args = {0};
+ constexpr uint32_t numBlocks = 1;
+ hello_world<<<numBlocks, nullptr, stream>>>(&args, sizeof(KernelArgs));
+ aclrtSynchronizeStream(stream);
+
+ aclrtDestroyStream(stream);
+ aclrtResetDevice(deviceId);
+ aclFinalize();
+ return 0;
+}
diff --git a/tests/projects/ascendc/mixed_binary/test.lua b/tests/projects/ascendc/mixed_binary/test.lua
new file mode 100644
index 000000000..0a36e62e4
--- /dev/null
+++ b/tests/projects/ascendc/mixed_binary/test.lua
@@ -0,0 +1,9 @@
+function main(t)
+ if not is_host("linux") then
+ return t:skip("wrong host platform")
+ end
+ if not os.getenv("ASCEND_HOME_PATH") then
+ return t:skip("ASCEND_HOME_PATH not set")
+ end
+ t:build()
+end
diff --git a/tests/projects/ascendc/mixed_binary/xmake.lua b/tests/projects/ascendc/mixed_binary/xmake.lua
new file mode 100644
index 000000000..046da8404
--- /dev/null
+++ b/tests/projects/ascendc/mixed_binary/xmake.lua
@@ -0,0 +1,6 @@
+add_rules("mode.debug", "mode.release")
+
+target("ascendc_mixed")
+ set_kind("binary")
+ add_files("src/main.asc", "src/helper.aicpu")
+ add_ascnpuarchs("dav-2201")